@@ -226,7 +226,11 @@ class RHKsm4:
 
         length = self._readb(np.uint16, 1)#first 2 bytes is the string length
         string = ''.join([chr(i) for i in np.fromfile(self._file, dtype=np.uint16, count=length)])
-        return string.rstrip('\x00')
+        try:
+            string.encode("utf8")
+            return string.rstrip('\x00')
+        except UnicodeEncodeError:
+            return ""
 
     def _readtime(self):
         '''Read RHK filetime object
@@ -803,14 +807,15 @@ class RHKObjectContainer:
         self.attrs[metaString + '_HarmonicFactor'] = self._sm4._readb(np.float64, 1)
         self.attrs[metaString + '_PhaseOffset'] = self._sm4._readb(np.float64, 1)
 
-        #Fix _FilterCutoffFrequency reading from some file versions
+        #Try FilterCutoffFrequency reading from some file versions
         try:
-            self.attrs[metaString + '_FilterCutoffFrequency'] = self._sm4._readb(np.float64, 1)
-        except:
             self.attrs[metaString + '_FilterCutoffFrequency'] = self._sm4._readstr()
-
-        self.attrs[metaString + '_FreqUnit'] = self._sm4._readstr()
-        self.attrs[metaString + '_PhaseUnit'] = self._sm4._readstr()
+            self.attrs[metaString + '_FreqUnit'] = self._sm4._readstr()
+            self.attrs[metaString + '_PhaseUnit'] = self._sm4._readstr()
+        except:
+            self.attrs[metaString + '_FilterCutoffFrequency'] = ""
+            self.attrs[metaString + '_FreqUnit'] = ""
+            self.attrs[metaString + '_PhaseUnit'] = ""
 
     def _read_PIControllerInfo(self, offset, metaString):
         ''' Read PI Controller Info for the current page.
@@ -1157,14 +1162,18 @@ class RHKPage(RHKObjectContainer):
         ysize = self.attrs['RHK_Ysize']
         xscale = self.attrs['RHK_Xscale']
         yscale = self.attrs['RHK_Yscale']
+        
+        ## Define coordinates labels
+        x_label = self.label + "_x"
+        y_label = self.label + "_y"
 
         # Reshape data
         if self._page_data_type == 0: # Image type
 
             data = raw_data.reshape(xsize, ysize)
 
-            coords = [('y', abs(yscale) * np.arange(ysize, dtype=np.float64)),
-                      ('x', abs(xscale) * np.arange(xsize, dtype=np.float64))]
+            coords = [(x_label, abs(xscale) * np.arange(xsize, dtype=np.float64)),
+                      (y_label, abs(yscale) * np.arange(ysize, dtype=np.float64))]
 
             # Check scale and adjust accordingly data orientation
             if xscale < 0:
@@ -1174,20 +1183,20 @@ class RHKPage(RHKObjectContainer):
 
         elif self._page_data_type == 1: # Line type
 
-            data = raw_data.reshape(ysize, xsize)
+            data = raw_data.reshape(ysize, xsize).transpose()
 
             xoffset = self.attrs['RHK_Xoffset']
-            coords = [('y', int(yscale) * np.arange(ysize, dtype=np.uint32)),
-                      ('x', xscale * np.arange(xsize, dtype=np.float64) + xoffset)]
+            coords = [(x_label, xscale * np.arange(xsize, dtype=np.float64) + xoffset),
+                      (y_label, int(yscale) * np.arange(ysize, dtype=np.uint32))]
 
             if self._line_type == 22: # Discrete spectroscopy has shape xsize*(ysize+1)
                 tmp = raw_data.reshape(xsize, ysize+1).transpose()
-                coords[1] = ('x', tmp[0])
+                coords[1] = (x_label, tmp[0])
                 data = tmp[1:]
 
         else:
 
             data = raw_data
-            coords = [('x', np.arange(xsize*ysize, dtype=np.uint32))]
+            coords = [(x_label, np.arange(xsize*ysize, dtype=np.uint32))]
 
         return data, coords
